@@ -20,16 +20,17 @@ NumericVector bucket_fill(NumericVector im,int x,int y,int z,NumericVector color
 NumericVector bucket_select(NumericVector im,int x,int y,int z,float sigma=0,bool high_connexity=false)
 {
   CId img = as<CId >(im);
-  CId out(img);
-
+  CIb out;
+  NumericVector v; //container for future output
   try{
     NumericVector color(img.spectrum());
     float opacity=1;
     img.draw_fill(x-1,y-1,z-1,color.begin(),opacity,out,sigma,high_connexity);
-    }
+    v = wrap(out);
+
+  }
   catch(CImgException &e){
     forward_exception_to_r(e);
-    
   }
-  return wrap(out);
+  return v;
 }
